@@ -257,6 +257,7 @@ struct hostrange_cmd_args
 #define IPMI_TOOL_WORKAROUND_FLAGS_SUN_2_0_SESSION                 0x00000080
 #define IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE          0x00000100
 #define IPMI_TOOL_WORKAROUND_FLAGS_NON_EMPTY_INTEGRITY_CHECK_VALUE 0x00000200
+#define IPMI_TOOL_WORKAROUND_FLAGS_ASSUME_IO_BASE_ADDRESS          0x00000400
 
 #define IPMI_TOOL_WORKAROUND_FLAGS_ACCEPT_SESSION_ID_ZERO_STR          "idzero"
 #define IPMI_TOOL_WORKAROUND_FLAGS_FORCE_PERMSG_AUTHENTICATION_STR     "forcepermsg"
@@ -268,6 +269,7 @@ struct hostrange_cmd_args
 #define IPMI_TOOL_WORKAROUND_FLAGS_SUN_2_0_SESSION_STR                 "sun20"
 #define IPMI_TOOL_WORKAROUND_FLAGS_OPEN_SESSION_PRIVILEGE_STR          "opensesspriv"
 #define IPMI_TOOL_WORKAROUND_FLAGS_NON_EMPTY_INTEGRITY_CHECK_VALUE_STR "integritycheckvalue"
+#define IPMI_TOOL_WORKAROUND_FLAGS_ASSUME_IO_BASE_ADDRESS_STR          "assumeio"
 
 #define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_IGNORE_SOL_PAYLOAD_SIZE     0x00000001
 #define IPMI_TOOL_SPECIFIC_WORKAROUND_FLAGS_IGNORE_SOL_PORT             0x00000002
