@@ -1080,7 +1080,7 @@ _normal_output_event (ipmi_sel_state_data_t *state_data, unsigned int flags)
 {
   char fmtbuf[IPMI_SEL_OUTPUT_BUFLEN+1];
   char outbuf[IPMI_SEL_OUTPUT_BUFLEN+1];
-  int outbuf_len;
+  int outbuf_len = 0;
   char *fmt;
   uint8_t event_type_code;
   uint8_t event_data2_flag;
@@ -1090,21 +1090,47 @@ _normal_output_event (ipmi_sel_state_data_t *state_data, unsigned int flags)
   uint8_t sensor_type;
   uint8_t event_data1_offset;
   int check_for_na = 0;
+  int read_oem_event_string = 0;
   int ret;
 
   assert (state_data);
   assert (!state_data->prog_data->args->legacy_output);
 
-  memset (outbuf, '\0', IPMI_SEL_OUTPUT_BUFLEN+1);
-  if ((outbuf_len = ipmi_sel_parse_read_record_string (state_data->sel_parse_ctx,
-                                                       "%e",
-                                                       outbuf,
-                                                       IPMI_SEL_OUTPUT_BUFLEN,
-                                                       flags)) < 0)
+  if (state_data->prog_data->args->output_oem_event_strings)
     {
-      if (_sel_parse_err_handle (state_data, "ipmi_sel_parse_read_record_string") < 0)
-        return (-1);
-      return (0);
+      unsigned int len;
+
+      memset (outbuf, '\0', IPMI_SEL_OUTPUT_BUFLEN+1);
+      if ((outbuf_len = ipmi_sel_parse_read_record_string (state_data->sel_parse_ctx,
+                                                           "%O",
+                                                           outbuf,
+                                                           IPMI_SEL_OUTPUT_BUFLEN,
+                                                           flags)) < 0)
+        {
+          if (_sel_parse_err_handle (state_data, "ipmi_sel_parse_read_record_string") < 0)
+            return (-1);
+          return (0);
+        }
+
+      len = strlen (outbuf);
+
+      if (len && strcmp (outbuf, IPMI_SEL_NA_STRING))
+        read_oem_event_string++;
+    }
+
+  if (!read_oem_event_string)
+    {
+      memset (outbuf, '\0', IPMI_SEL_OUTPUT_BUFLEN+1);
+      if ((outbuf_len = ipmi_sel_parse_read_record_string (state_data->sel_parse_ctx,
+                                                           "%e",
+                                                           outbuf,
+                                                           IPMI_SEL_OUTPUT_BUFLEN,
+                                                           flags)) < 0)
+        {
+          if (_sel_parse_err_handle (state_data, "ipmi_sel_parse_read_record_string") < 0)
+            return (-1);
+          return (0);
+        }
     }
 
   if (state_data->prog_data->args->comma_separated_output)
@@ -1122,6 +1148,10 @@ _normal_output_event (ipmi_sel_state_data_t *state_data, unsigned int flags)
         pstdout_printf (state_data->pstate, " | %s", IPMI_SEL_NA_STRING);
     }
 
+  /* we're done if we got an OEM event string */
+  if (read_oem_event_string)
+    goto out;
+
   if ((ret = _get_system_event_record_info (state_data,
                                             &event_type_code,
                                             &event_data2_flag,
@@ -1330,23 +1360,49 @@ static int
 _normal_output_oem_data (ipmi_sel_state_data_t *state_data, unsigned int flags)
 {
   char outbuf[IPMI_SEL_OUTPUT_BUFLEN+1];
+  int read_oem_event_string = 0;
   int outbuf_len;
 
   assert (state_data);
   assert (!state_data->prog_data->args->legacy_output);
 
-  memset (outbuf, '\0', IPMI_SEL_OUTPUT_BUFLEN+1);
-  if ((outbuf_len = ipmi_sel_parse_read_record_string (state_data->sel_parse_ctx,
-                                                       "%o",
-                                                       outbuf,
-                                                       IPMI_SEL_OUTPUT_BUFLEN,
-                                                       flags)) < 0)
+  if (state_data->prog_data->args->output_oem_event_strings)
     {
-      if (_sel_parse_err_handle (state_data, "ipmi_sel_parse_read_record_string") < 0)
-        return (-1);
-      return (0);
+      unsigned int len;
+      
+      memset (outbuf, '\0', IPMI_SEL_OUTPUT_BUFLEN+1);
+      if ((outbuf_len = ipmi_sel_parse_read_record_string (state_data->sel_parse_ctx,
+                                                           "%O",
+                                                           outbuf,
+                                                           IPMI_SEL_OUTPUT_BUFLEN,
+                                                           flags)) < 0)
+        {
+          if (_sel_parse_err_handle (state_data, "ipmi_sel_parse_read_record_string") < 0)
+            return (-1);
+          return (0);
+        }
+      
+      len = strlen (outbuf);
+      
+      if (len && strcmp (outbuf, IPMI_SEL_NA_STRING))
+        read_oem_event_string++;
     }
 
+  if (!read_oem_event_string)
+    {
+      memset (outbuf, '\0', IPMI_SEL_OUTPUT_BUFLEN+1);
+      if ((outbuf_len = ipmi_sel_parse_read_record_string (state_data->sel_parse_ctx,
+                                                           "%o",
+                                                           outbuf,
+                                                           IPMI_SEL_OUTPUT_BUFLEN,
+                                                           flags)) < 0)
+        {
+          if (_sel_parse_err_handle (state_data, "ipmi_sel_parse_read_record_string") < 0)
+            return (-1);
+          return (0);
+        }
+    }
+  
   if (state_data->prog_data->args->comma_separated_output)
     {
       if (outbuf_len)
@@ -1933,7 +1989,7 @@ _display_sel_records (ipmi_sel_state_data_t *state_data)
         }
     }
 
-  if (args->interpret_oem_data)
+  if (args->interpret_oem_data || args->output_oem_event_strings)
     {
       if (ipmi_get_oem_data (state_data->pstate,
                              state_data->ipmi_ctx,
