@@ -739,7 +739,7 @@ _output_sensor (ipmi_sensors_state_data_t *state_data,
       rv = ipmi_sensors_detailed_output (state_data,
                                          sdr_record,
                                          sdr_record_len,
-					 sensor_number_base + shared_sensor_number_offset,
+                                         sensor_number_base + shared_sensor_number_offset,
                                          sensor_reading,
                                          event_message_list,
                                          event_message_list_len);
@@ -813,7 +813,8 @@ _display_sensors (ipmi_sensors_state_data_t *state_data)
           /* at this point shouldn't have record id not found error */
           pstdout_fprintf (state_data->pstate,
                            stderr,
-                           "ipmi_sdr_cache_search_record_id: %s\n",
+                           "ipmi_sdr_cache_search_record_id: 0x%02X %s\n",
+                           output_record_ids[i],
                            ipmi_sdr_cache_ctx_errormsg (state_data->sdr_cache_ctx));
           goto cleanup;
         }
