@@ -35,14 +35,6 @@ extern "C" {
 #define IPMI_NET_FN_OEM_DELL_GENERIC_RQ 0x30
 #define IPMI_NET_FN_OEM_DELL_GENERIC_RS 0x31
 
-/*
- * Dell Xanadu II
- * Dell Xanadu III
- */
-/* achu: not official names, named based on use context */
-#define IPMI_NET_FN_OEM_DELL_XANADU_RQ 0x34
-#define IPMI_NET_FN_OEM_DELL_XANADU_RS 0x35
-
 /*******************************************
  * Fujitsu                                 *
  *******************************************/
@@ -64,6 +56,21 @@ extern "C" {
 #define IPMI_NET_FN_OEM_IBM_LED_RQ 0x3A
 #define IPMI_NET_FN_OEM_IBM_LED_RS 0x3B
 
+/*******************************************
+ * Intel                                   *
+ *******************************************/
+  
+/*
+ * Intel S5500WB/Penguin Computing Relion 700
+ */
+
+/* achu: not official names, named based on use context */
+#define IPMI_NET_FN_OEM_INTEL_GENERIC_RQ 0x30
+#define IPMI_NET_FN_OEM_INTEL_GENERIC_RS 0x31
+
+#define IPMI_NET_FN_OEM_INTEL_CONFIG_RQ 0x32
+#define IPMI_NET_FN_OEM_INTEL_CONFIG_RS 0x33
+
 /*******************************************
  * Inventec                                *
  *******************************************/
@@ -76,12 +83,15 @@ extern "C" {
 #define IPMI_NET_FN_OEM_INVENTEC_GENERIC_RQ 0x30
 #define IPMI_NET_FN_OEM_INVENTEC_GENERIC_RS 0x31
 
+#define IPMI_NET_FN_OEM_INVENTEC_SPECIFIC_RQ 0x34
+#define IPMI_NET_FN_OEM_INVENTEC_SPECIFIC_RS 0x35
+
 /*******************************************
  * Quanta                                *
  *******************************************/
 
 /*
- * Quanta S99Q/Dell TS12-TY
+ * Quanta S99Q/Dell FS12-TY
  */
 /* achu: not official names, named based on use context */
 #define IPMI_NET_FN_OEM_QUANTA_GENERIC_RQ 0x30
