@@ -196,12 +196,6 @@ _ipmi_dump_inband_packet (int fd,
         goto cleanup;
     }
   
-  if (pkt_len <= indx)
-    {
-      rv = 0;
-      goto cleanup;
-    }
-
   /* Dump unexpected stuff */
 
   if ((pkt_len - indx) > 0)
@@ -238,6 +232,22 @@ _ipmi_dump_inband_packet (int fd,
       goto cleanup;
     }
 
+#if WITH_RAWDUMPS
+  /* For those vendors that get confused when they see the nice output
+   * and want the hex output
+   */
+  if (ipmi_dump_hex (fd,
+                     prefix,
+                     hdr,
+		     trlr,
+		     pkt,
+		     pkt_len) < 0)
+    {
+      ERRNO_TRACE (errno);
+      goto cleanup;
+    }
+#endif
+
   rv = 0;
  cleanup:
   fiid_obj_destroy (obj_kcs_hdr);
