@@ -1877,6 +1877,98 @@ ipmi_get_oem_sensor_type_message (uint32_t manufacturer_id,
         }
     }
 
+  /* 
+   * OEM Interpretation
+   *
+   * Fujitsu iRMC S1 / iRMC S2
+   *
+   */
+  if (manufacturer_id == IPMI_IANA_ENTERPRISE_ID_FUJITSU
+      && (product_id >= IPMI_FUJITSU_PRODUCT_ID_MIN 
+          && product_id <= IPMI_FUJITSU_PRODUCT_ID_MAX))
+    {
+      switch (sensor_type)
+        {
+        case IPMI_SENSOR_TYPE_OEM_FUJITSU_I2C_BUS:
+          return (_get_event_message (offset,
+                                      buf,
+                                      buflen,
+                                      ipmi_sensor_type_oem_fujitsu_i2c_bus_max_index,
+                                      ipmi_sensor_type_oem_fujitsu_i2c_bus));
+        case IPMI_SENSOR_TYPE_OEM_FUJITSU_SYSTEM_POWER_CONSUMPTION:
+          return (_get_event_message (offset,
+                                      buf,
+                                      buflen,
+                                      ipmi_sensor_type_oem_fujitsu_system_power_consumption_max_index,
+                                      ipmi_sensor_type_oem_fujitsu_system_power_consumption));
+        case IPMI_SENSOR_TYPE_OEM_FUJITSU_MEMORY_STATUS:
+          return (_get_event_message (offset,
+                                      buf,
+                                      buflen,
+                                      ipmi_sensor_type_oem_fujitsu_memory_status_max_index,
+                                      ipmi_sensor_type_oem_fujitsu_memory_status));
+        case IPMI_SENSOR_TYPE_OEM_FUJITSU_MEMORY_CONFIG:
+          return (_get_event_message (offset,
+                                      buf,
+                                      buflen,
+                                      ipmi_sensor_type_oem_fujitsu_memory_config_max_index,
+                                      ipmi_sensor_type_oem_fujitsu_memory_config));
+        case IPMI_SENSOR_TYPE_OEM_FUJITSU_MEMORY:
+          return (_get_event_message (offset,
+                                      buf,
+                                      buflen,
+                                      ipmi_sensor_type_oem_fujitsu_memory_max_index,
+                                      ipmi_sensor_type_oem_fujitsu_memory));
+        case IPMI_SENSOR_TYPE_OEM_FUJITSU_HW_ERROR:
+          return (_get_event_message (offset,
+                                      buf,
+                                      buflen,
+                                      ipmi_sensor_type_oem_fujitsu_hw_error_max_index,
+                                      ipmi_sensor_type_oem_fujitsu_hw_error));
+        case IPMI_SENSOR_TYPE_OEM_FUJITSU_SYS_ERROR:
+          return (_get_event_message (offset,
+                                      buf,
+                                      buflen,
+                                      ipmi_sensor_type_oem_fujitsu_sys_error_max_index,
+                                      ipmi_sensor_type_oem_fujitsu_sys_error));
+        case IPMI_SENSOR_TYPE_OEM_FUJITSU_FAN_STATUS:
+          return (_get_event_message (offset,
+                                      buf,
+                                      buflen,
+                                      ipmi_sensor_type_oem_fujitsu_fan_status_max_index,
+                                      ipmi_sensor_type_oem_fujitsu_fan_status));
+        case IPMI_SENSOR_TYPE_OEM_FUJITSU_PSU_STATUS:
+          return (_get_event_message (offset,
+                                      buf,
+                                      buflen,
+                                      ipmi_sensor_type_oem_fujitsu_psu_status_max_index,
+                                      ipmi_sensor_type_oem_fujitsu_psu_status));
+        case IPMI_SENSOR_TYPE_OEM_FUJITSU_PSU_REDUNDANCY:
+          return (_get_event_message (offset,
+                                      buf,
+                                      buflen,
+                                      ipmi_sensor_type_oem_fujitsu_psu_redundancy_max_index,
+                                      ipmi_sensor_type_oem_fujitsu_psu_redundancy));
+        case IPMI_SENSOR_TYPE_OEM_FUJITSU_FLASH:
+          return (_get_event_message (offset,
+                                      buf,
+                                      buflen,
+                                      ipmi_sensor_type_oem_fujitsu_flash_max_index,
+                                      ipmi_sensor_type_oem_fujitsu_flash));
+        case IPMI_SENSOR_TYPE_OEM_FUJITSU_CONFIG_BACKUP:
+          return (_get_event_message (offset,
+                                      buf,
+                                      buflen,
+                                      ipmi_sensor_type_oem_fujitsu_config_backup_max_index,
+                                      ipmi_sensor_type_oem_fujitsu_config_backup));
+        /* These are reserved */
+        case IPMI_SENSOR_TYPE_OEM_FUJITSU_COMMUNICATION:
+        case IPMI_SENSOR_TYPE_OEM_FUJITSU_EVENT:
+        default:
+          break;
+        }
+    }
+
   SET_ERRNO (EINVAL);
   return (-1);
 }
